/*
 *  nwdf.c
 *
 *  df like volume list
 *
 *  Copyright (C) 1997 by Henrik Olsen
 *  with heavy borrowing from nwvolinfo.c
 *  Copyright (C) 1996 by Volker Lendecke
 *
 */

#include <stdio.h>
#include <unistd.h>
#include <ctype.h>
#include <stdlib.h>
#include "ncplib.h"

static char *progname;

static void
usage(void)
{
	fprintf(stderr, "usage: %s [options] pattern\n", progname);
	return;
}

static void
help(void)
{
	printf("\n");
	printf("usage: %s [options]\n", progname);
	printf("\n"
	       "-h             Print this help text\n"
	       "-S server      Server name to be used\n"
	       "-U username    Username sent to server\n"
	       "-P password    Use this password\n"
	       "-n             Do not use any password\n"
	       "-C             Don't convert password to uppercase\n"
	       "-k             only list volumes, without explanation\n"
	       "\n");
}

int
main(int argc, char **argv)
{
	struct ncp_conn *conn;
	struct ncp_volume_info o;
	struct ncp_file_server_info info;
	
	long err;
	int opt;
	int numk;
	__u16 type = 0;

	progname = argv[0];

	if ((conn = ncp_initialize(&argc, argv, 1, &err)) == NULL)
	{
		com_err(argv[0], err, "when initializing");
		return 1;
	}
	while ((opt = getopt(argc, argv, "h?k")) != EOF)
	{
		switch (opt)
		{
		case 'k':
			type = 1;
			break;
		case 'h':
		case '?':
			help();
			exit(1);
		default:
			usage();
			exit(1);
		}
	}

	if (optind < argc)
	{
		usage();
		exit(1);
	}
	if (ncp_get_file_server_information(conn, &info) != 0)
	{
		perror("Could not get server information");
		ncp_close(conn);
		return 1;
	}
	if (!type)
	{
		printf("Volume             1024-blocks  Used Available Capacity\n");
	}
	opt = 0;
	while (!ncp_get_volume_info_with_number(conn, opt, &o) &&
	       info.NumberMountedVolumes > opt)
	{
		numk = o.sectors_per_block / 2;
		if(o.total_blocks * numk)
		{
			o.free_blocks += o.purgeable_blocks;
			printf("%-20s%8d%8d%9d%7d%%\n",
			       (char *)&(o.volume_name),
			       o.total_blocks * numk,
			       (o.total_blocks - o.free_blocks)* numk,
			       o.free_blocks * numk,
			       (o.total_blocks - o.free_blocks)*100/o.total_blocks);
		}
		opt++;
	}
	ncp_close(conn);
	return 0;
}
